import type { ClientFilter, ClientFilterName, ClientFilterSchema } from './clientFilter';
/**
 * NodeEnv client filter function.
 * @remarks
 * This will return true when the current node env matches target parameters.
 * @param envs - Environments to target.
 * @public
 */
export declare function nodeEnvFilter(envs: string[]): boolean;
/**
 * NodeEnvParams
 *
 * @example
 * ```json
 * {
 *    "envs": ["development", "testing"],
 * }
 * ```
 *
 * @public
 */
export type NodeEnvParams = {
    /**
     * Envs to target.
     */
    readonly envs: string[];
};
/**
 * NodeEnvSchema type.
 *
 * @remarks
 * JSON schema type.
 *
 * @public
 */
export type NodeEnvSchema = ClientFilterSchema<typeof ClientFilterName.nodeEnv, NodeEnvParams>;
/**
 * NodeEnv client filter DI interface.
 * @public
 */
export interface NodeEnv extends ClientFilter<NodeEnvParams> {
    /**
     * @remarks
     * Running in development mode.
     */
    readonly isDevelopment: boolean;
    /**
     * @remarks
     * Running in test mode.
     */
    readonly isTesting: boolean;
    /**
     * @remarks
     * Running in production mode.
     */
    readonly isProduction: boolean;
}
/**
 * Default NodeEnv DI implementation.
 * @public
 */
export declare class DefaultNodeEnv implements NodeEnv {
    /** {@inheritDoc ClientFilter.filter} */
    filter(params: NodeEnvParams): boolean;
    /** {@inheritDoc NodeEnv.isDevelopment} */
    get isDevelopment(): boolean;
    /** {@inheritDoc NodeEnv.isTesting} */
    get isTesting(): boolean;
    /** {@inheritDoc NodeEnv.isProduction} */
    get isProduction(): boolean;
}
/**
 * NodeEnv DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export declare const NodeEnv: import("@microsoft/fast-foundation").InterfaceSymbol<NodeEnv>;
//# sourceMappingURL=nodeEnv.d.ts.map