import { DI } from '@microsoft/fast-foundation';
import { logger } from './logger';
/**
 * NodeEnv client filter function.
 * @remarks
 * This will return true when the current node env matches target parameters.
 * @param envs - Environments to target.
 * @public
 */
export function nodeEnvFilter(envs) {
    if (!envs) {
        logger.warn('NodeEnv filter parameters must include envs.');
        return true;
    }
    return !!process.env.NODE_ENV && envs.includes(process.env.NODE_ENV);
}
/**
 * Default NodeEnv DI implementation.
 * @public
 */
export class DefaultNodeEnv {
    /** {@inheritDoc ClientFilter.filter} */
    filter(params) {
        return nodeEnvFilter(params === null || params === void 0 ? void 0 : params.envs);
    }
    /** {@inheritDoc NodeEnv.isDevelopment} */
    get isDevelopment() {
        return nodeEnvFilter(['development']);
    }
    /** {@inheritDoc NodeEnv.isTesting} */
    get isTesting() {
        return nodeEnvFilter(['testing', 'test']);
    }
    /** {@inheritDoc NodeEnv.isProduction} */
    get isProduction() {
        return nodeEnvFilter(['production']);
    }
}
/**
 * NodeEnv DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const NodeEnv = DI.createInterface((x) => x.transient(DefaultNodeEnv));
