import { DI } from '@microsoft/fast-foundation';
import { logger } from './logger';
/**
 * Percentage client filter function.
 * @remarks
 * This will return true a certain percentage of the time.
 * @param percent - The percent of the time to pass, a numeric value between 0 and 1.
 * @param random - Math.random() generated floating-point.
 * @public
 */
export function percentageFilter(percent, random = Math.random()) {
    const withinRange = percent >= 0 && percent <= 1;
    if (!withinRange) {
        logger.warn('Percentage filter parameters must include a numeric percent between 0 and 1.');
        return true;
    }
    return random < percent;
}
/**
 * Default Percentage DI implementation.
 * @public
 */
export class DefaultPercentage {
    /** {@inheritDoc ClientFilter.filter} */
    filter(params) {
        return percentageFilter(params === null || params === void 0 ? void 0 : params.percent, params === null || params === void 0 ? void 0 : params.random);
    }
}
/**
 * Percentage DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const Percentage = DI.createInterface((x) => x.transient(DefaultPercentage));
